@@ -32,6 +32,9 @@ fill_template = function(template, values, required=c()) {
              paste(setdiff(required, keys), collapse=", "))
 
     upd = keys %in% names(values)
+    is_num = sapply(values, is.numeric)
+    if (length(is_num) > 0)
+        values[is_num] = format(values[is_num], scientific=FALSE, trim=TRUE)
     vals[upd] = unlist(values)[keys[upd]]
     if (any(is.na(vals)))
         stop("Template values required but not provided: ",
@@ -62,7 +65,7 @@ vec_lookup = list(
 #' @keywords internal
 wrap_error = function(call) {
     structure(class = c("worker_error", "condition"),
-              list(message=geterrmessage(), call=call));
+              list(message=geterrmessage(), call=call))
 }
 
 #' Message format for logging
